@@ -15,12 +15,13 @@ from applescript import AppleScript, kMissingValue
 
 from photoscript.utils import ditto, findfiles
 
+from .exceptions import AppleScriptError
 from .script_loader import run_script
 from .utils import get_os_version
 
 MACOS_VERSION = get_os_version()
 
-""" In Catalina / Photos 5+, UUIDs in AppleScript have suffix that doesn't 
+""" In Catalina / Photos 5+, UUIDs in AppleScript have suffix that doesn't
     appear in actual database value.  These need to be dropped to be compatible
     with osxphotos """
 UUID_SUFFIX_PHOTO = "/L0/001"
@@ -51,11 +52,6 @@ def uuid_to_id(uuid: str, suffix: str) -> tuple[str, str]:
     return uuid, id_
 
 
-class AppleScriptError(Exception):
-    def __init__(self, *message):
-        super().__init__(*message)
-
-
 class PhotosLibrary:
     def __init__(self):
         """create new PhotosLibrary object and launch Photos"""
@@ -74,28 +70,32 @@ class PhotosLibrary:
         """open a library and wait for delay for user to acknowledge in Photos"""
         # Note: Unlike the other AppleScript scripts, this one is not included in photoscript.applescript
         # because, for reasons I cannot explain, it fails to run if included there
+        # Note: Script changed to Quit Photos and use 'do shell script "open -a Photos <library path>"'
+        # to open Library.
         if not pathlib.Path(library_path).is_dir():
             raise ValueError(f"{library_path} does not appear to be a Photos library")
         self.activate()
         script = AppleScript(
             f"""
             set tries to 0
+            set libraryPath to "{library_path}"
             repeat while tries < 5
                 try
-                    tell application "Photos"
-                        activate
-                        delay 3 
-                        open POSIX file "{library_path}"
-                        delay {delay}
-                    end tell
-                    set tries to 5
+                    tell application "Photos" to quit
+                    delay 2
+                    do shell script "open -a Photos " & quoted form of libraryPath
+                    delay {delay}
+                    set tries to 99
                 on error
                     set tries to tries + 1
                 end try
             end repeat
+            return tries
         """
         )
-        script.run()
+        tries = script.run()
+        if tries != 99:
+            raise RuntimeError(f"Photos failed to open {library_path} after {tries} tries")
 
     @property
     def running(self):
